%%
%******************************************************************************
% The function SkelMusMetab_Cdot lists the system of differential equations 
% governing the transport and metabolism of chemical species in skeletal muscle. 
% It is based on dynamic mass balances of all the species.
%******************************************************************************

function [Cdot] = SkelMusMetab_Cdot(t,C)
       
format long 

global URR0 Rflux0 Ca Cb0 Cc0 C0 MgATPADP0
global Vmus Qm Qisch Tmax Mm Lam Vmax Kf Kb Kps Krs Sigma
global Q UPT REL URR AVD Ctrl Rflux PROD UTIL MRR O2CO2 MgATPADP

%%
%******************************************************************************
% This section sets the muscle blood flow (Q), blood volume (Vb), ISF volume 
% (Visf), and cell volume (Vc) required for computing the metabolic dynamics.
%******************************************************************************

Vb = 0.07*Vmus;
Visf = 0.13*Vmus;
Vc = 0.72*Vmus;
Vm = 0.08*Vmus;

% Blood flow dynamics (step decrease)
if ((t <= 5) || (t > 35))
   Q = Qm;                   % Resting muscle blood flow
else
   Q = Qisch;                % Ischemic muscle blood flow
end

% % Blood flow dynamics
% if (t <= 5)
%    Q = Qm;                          % Resting muscle blood flow
% elseif (t <= 35)
%    Q = Qisch*(1-exp(-(t-5)/0.05));  % Ischemic muscle blood flow
% else 
%    Q = Qm*(1-exp(-(t-35)/0.05));
% end 

% % Blood flow dynamics
% if (t <= 5)
%    Q = Qm;                                  % Resting muscle blood flow
% elseif (t <= 35)
%    Q = Qisch + (Qm-Qisch)*exp(-(t-5)/0.1);  % Ischemic muscle blood flow
% else
%    Q = Qm + (Qisch-Qm)*exp(-(t-35)/0.1);
% end 

%%
%******************************************************************************
% This section sets the capillary blood and tissue cell concentrations (Cb and
% Cc) of all the chemical species at current time and then calculates total O2 
% and CO2 concentrations in ARTERIAL blood, CAPILLARY/VENOUS blood, and tissue
% cells. The calculation for total O2 and CO2 concentrations is done using the 
% external functions O2Tot_Blood, O2Tot_Cells, CO2Tot_Blood and CO2Tot_Cells.
%******************************************************************************

Cb = zeros(8,1);       % Initialization of Cb
Cc = zeros(30,1);      % Initialization of Cc
Cb = C(1:8);           % Blood species concentrations
Cc = C(9:38);          % Cells species concentrations

CO2a = Ca(7);          % Free CO2 concentration in arterial blood (mmol/L)
CO2b = Cb(7);          % Free CO2 concentration in capillary/venous blood (mmol/L)
CO2c = Cc(7);          % Free CO2 concentration in tissue cells (mmol/L)
O2a = Ca(8);           % Free O2 concentration in arterial blood (mmol/L)
O2b = Cb(8);           % Free O2 concentration in capillary/venous blood (mmol/L)
O2c = Cc(8);           % Free O2 concentration in tissue cells (mmol/L)

[SHbCO2a,CHbCO2a,CHCO3a,CO2aTot] = CO2Tot_Blood(CO2a);
[SHbCO2b,CHbCO2b,CHCO3b,CO2bTot] = CO2Tot_Blood(CO2b);
[CHCO3c,CO2cTot] = CO2Tot_Cells(CO2c);
[SHbO2a,CHbO2a,O2aTot] = O2Tot_Blood(O2a);
[SHbO2b,CHbO2b,O2bTot] = O2Tot_Blood(O2b);
[SMbO2c,CMbO2c,O2cTot] = O2Tot_Cells(O2c);

Hct = 0.45; CHbTot = 5.2; CMbTot = 0.5; 
StO2 = (Vb*CHbO2b/4.0 + (Vc+Vm)*CMbO2c)/(Vb*Hct*CHbTot + (Vc+Vm)*CMbTot);

O2CO2 = [Cb(8),SHbO2b,O2bTot,Cc(8),SMbO2c,O2cTot,StO2,...
         Cb(7),CO2bTot,Cc(7),CO2cTot]';

%%
%******************************************************************************
% This section calculates the uptake (UPT), release (REL), uptake-release rates
% (URR), and arterial-venous differences (AVD) of the 8 species which undergo 
% blood-tissue exchange.
% NOTE: Actually the Tmax and Mm parameter values are passed here from the 
% SkelMusMetab_driver routine. So, we do not need to set these here again.
%*****************************************************************************

UPT = zeros(8,1);                          % Initialization of UPT
REL = zeros(8,1);                          % Initialization of REL
URR = zeros(8,1);                          % Initialization of URR
AVD = zeros(8,1);                          % Initialization of AVD

UPT(1) = Tmax(1)*Cb(1)/(Mm(1) + Cb(1));    % Uptake of GLU from blood
REL(1) = Tmax(1)*Cc(1)/(Mm(1) + Cc(1));    % Release of GLU to blood
UPT(2) = Tmax(2)*Cb(2)/(Mm(2) + Cb(2));    % Uptake of Pyr from blood
REL(2) = Tmax(2)*Cc(2)/(Mm(2) + Cc(2));    % Release of Pyr to blood
UPT(3) = Tmax(3)*Cb(3)/(Mm(3) + Cb(3));    % Uptake of LAC from blood
REL(3) = Tmax(3)*Cc(3)/(Mm(3) + Cc(3));    % Release of LAC to blood
UPT(6) = Tmax(6)*Cb(6)/(Mm(6) + Cb(6));    % Uptake of FFA from blood
REL(6) = Tmax(6)*Cc(6)/(Mm(6) + Cc(6));    % Release of FFA to blood

UPT(4) = Lam(4)*Cb(4);                     % Uptake of ALA from blood
REL(4) = Lam(4)*Cc(4);                     % Release of ALA to blood
UPT(5) = Lam(5)*Cb(5);                     % Uptake of GLC from blood
REL(5) = Lam(5)*Cc(5);                     % Release of GLC to blood
UPT(7) = Lam(7)*Cb(7);                     % Uptake of CO2 from blood
REL(7) = Lam(7)*Cc(7);                     % Release of CO2 to blood
UPT(8) = Lam(8)*Cb(8);                     % Uptake of O2 from blood
REL(8) = Lam(8)*Cc(8);                     % Release of O2 to blood

URR = UPT - REL;                           % URR for all 8 species

AVD(1:6) = Q*(Ca(1:6) - Cb(1:6));          % AVD for first 6 species
AVD(7) = Q*(CO2aTot - CO2bTot);            % AVD for CO2
AVD(8) = Q*(O2aTot - O2bTot);              % AVD for O2

%%
%**************************************************************************
% This section define the free and bound forms of ATP/ADP. The idea is 
% that assume total Mg concentration in cytosol and mitochondria as 
% constant (10 mM). Then from the total ATP/ADP, determine the free and 
% bound forms of ATP/ADP from the equilibrium binding relationships.
%**************************************************************************

Mg = MgATPADP0(1);          % Cell (Cytosol/Mitochondria) Mg concentration [mM]
ATP_c_t = Cc(28);           % Cytosol total ATP concentration [mM]
ADP_c_t = Cc(29);           % Cytosol total ADP concentration [mM]  

[Mg_c_f,ATP_c_f,ADP_c_f,ATP_c_b,ADP_c_b] = MgATPADP_rev(Mg,ATP_c_t,ADP_c_t);

% Since the partition coefficient is based on total ATP/ADP concentrations, 
% calculate total ATP/ADP in mitochondria based on sigma. Then calculate
% free ATP/ADP in mitochondria based on equilibrium relationships.

ATP_m_t = Sigma(28)*ATP_c_t;   % Mitochondrial total ATP concentration [mM]
ADP_m_t = Sigma(29)*ADP_c_t;   % Mitochondrial total ADP  concentration [mM]

[Mg_m_f,ATP_m_f,ADP_m_f,ATP_m_b,ADP_m_b] = MgATPADP_rev(Mg,ATP_m_t,ADP_m_t);

MgATPADP = [Mg,ATP_c_f,ATP_c_b,ATP_c_t,ADP_c_f,ADP_c_b,ADP_c_t,Mg_c_f, ...
            ATP_m_f,ATP_m_b,ATP_m_t,ADP_m_f,ADP_m_b,ADP_m_t,Mg_m_f]';

%%
%******************************************************************************
% This section computes the Ctrl values and fluxes for the 26 reactions. For
% reactions where a pair of energy metabolites are couples, Ctrl is  Vmax 
% times the controller term, else Ctrl = Vmax. 
% NOTE: Actually the Vmax, Km, Kps and Krs parameter values are passed here from
% the SkelMusMetab_driver code. So, we do not need to set these here again.
%******************************************************************************

Ctrl = ones(26,1);
Rflux = zeros(26,1);

% Set on/off switches for inhibition
epsilon01 = 1.0;    % Glucose Utilization
epsilon10 = 0.0;    % PDH reaction
epsilon15 = 0.0;    % Citrate production
epsilon24 = 1.0;    % ATP hydrolysis

delta01 = 1.0;      % Glucose Utilization
delta03 = 1.0;      % Glycogen Utilization
delta10 = 0.0;      % PDH reaction
delta15 = 0.0;      % Citrate production
delta16 = 0.0;      % AKG production
delta17 = 0.0;      % SCoA production

% Glucose Utilization:  GLU + ATP -> G6P + ADP
Ctrl(1) = (1.0 / (1.0 + delta01*Cc(9)/Kb(1))) * ...
    ((ATP_c_f/ADP_c_f) / (Kps(1) + ATP_c_f/ADP_c_f));
Rflux(1) = Vmax(1) * Ctrl(1) * (Cc(1)/Kf(1)) / ...
    (1.0 + epsilon01*Cc(9)/Kb(1) + Cc(1)/Kf(1));

% Glycogen Synthesis:  G6P + ATP -> GLY + ADP + 2Pi
Ctrl(2) = (ATP_c_f/ADP_c_f) / (Kps(2) + ATP_c_f/ADP_c_f); 
Rflux(2) = Vmax(2) * Ctrl(2) * Cc(9) / (Kf(2) + Cc(9));

% Glycogen Utilization:  GLY + Pi -> G6P
Ctrl(3) = (Cc(30)/ATP_c_f) / (delta03*Kps(3) + Cc(30)/ATP_c_f);  
Rflux(3) = Vmax(3) * Ctrl(3) * Cc(10)*Cc(24) / (Kf(3) + Cc(10)*Cc(24));

% G6P Breakdown:  G6P + ATP -> 2GA3P + ADP
Ctrl(4) = (ATP_c_f/ADP_c_f) / (Kps(4) + ATP_c_f/ADP_c_f);
Rflux(4) = Vmax(4) * Ctrl(4) * Cc(9) / (Kf(4) + Cc(9));

% GA3P Breakdown:  GA3P + Pi + NAD -> BPG + NADH
Ctrl(5) = (Cc(27)/Cc(26)) / (Krs(5) + Cc(27)/Cc(26)); 
Rflux(5) = Vmax(5) * Ctrl(5) * Cc(11)*Cc(24) / (Kf(5) + Cc(11)*Cc(24));

% Pyruvate Production:  BPG + 2ADP -> PYR + 2ATP
Ctrl(6) = (ADP_c_f/ATP_c_f) / (Kps(6) + ADP_c_f/ATP_c_f);
Rflux(6) = Vmax(6) * Ctrl(6) * Cc(12) / (Kf(6) + Cc(12));

% Pyruvate Reduction:  PYR + NADH -> LAC + NAD
Ctrl(7) = (Cc(26)/Cc(27)) / (Krs(7) + Cc(26)/Cc(27));
Rflux(7) = Vmax(7) * Ctrl(7) * Cc(2) / (Kf(7) + Cc(2));

% Lactate Oxidation:  LAC + NAD -> PYR + NADH
Ctrl(8) = (Cc(27)/Cc(26)) / (Krs(8) + Cc(27)/Cc(26));
Rflux(8) = Vmax(8) * Ctrl(8) * Cc(3) / (Kf(8) + Cc(3));

% Alanine Production:  PYR -> ALA
Rflux(9) = Vmax(9) * Cc(2) / (Kf(9) + Cc(2));

% Pyruvate Oxidation:  PYR + CoA + NAD -> ACoA + NADH + CO2
Ctrl(10) = ((Cc(27)*Sigma(27)/(Cc(26)*Sigma(26))) / ...
    (Krs(10) + Cc(27)*Sigma(27)/(Cc(26)*Sigma(26)))) * ...
    ((ADP_m_f/ATP_m_f) /(delta10*Kps(10) + ADP_m_f/ATP_m_f));
Rflux(10) = Vmax(10) * Ctrl(10) * (Cc(2)*Sigma(2)*Cc(25)*Sigma(25)/Kf(10)) / ...
    (1.0 + epsilon10*Cc(15)*Cc(26)*Sigma(26)/Kb(10) + ...
    Cc(2)*Sigma(2)*Cc(25)*Sigma(25)/Kf(10));

% Lipolysis:  TGL -> GLC + 3FFA
Rflux(11) = Vmax(11) * Cc(13) / (Kf(11) + Cc(13)); 

% Triglyceride Synthesis:  GA3P + 3FAC + NADH -> TGL + 3CoA + NAD + Pi
Ctrl(12) = (Cc(26)/Cc(27)) / (Krs(12) + Cc(26)/Cc(27));
Rflux(12) = Vmax(12) * Ctrl(12) * Cc(11)*Cc(14) / (Kf(12) + Cc(11)*Cc(14));
    
% Free Fatty Acid Utilization:  FFA + CoA + 2ATP -> FAC + 2ADP + 2Pi
Ctrl(13) = (ATP_c_f/ADP_c_f) / (Kps(13) + ATP_c_f/ADP_c_f);  
Rflux(13) = Vmax(13) * Ctrl(13) * Cc(6)*Cc(25) / (Kf(13) + Cc(6)*Cc(25));

% FAC Oxidation:  FAC + 7CoA + 14NAD -> 8ACoA + 14NADH
Ctrl(14) = (Cc(27)*Sigma(27)/(Cc(26)*Sigma(26))) / ...
    (Krs(14) + Cc(27)*Sigma(27)/(Cc(26)*Sigma(26)));
Rflux(14) = Vmax(14) * Ctrl(14) * Cc(14)*Sigma(14)*Cc(25)*Sigma(25) / ...
    (Kf(14) + Cc(14)*Sigma(14)*Cc(25)*Sigma(25));

% Citrate Production:  ACoA + OXA -> CIT + CoA
Ctrl(15) = (ADP_m_f/ATP_m_f) / (delta15*Kps(15) + ADP_m_f/ATP_m_f);
Rflux(15) = Vmax(15) * Ctrl(15) * (Cc(15)*Cc(21)/Kf(15)) / ...
    (1.0 + epsilon15*Cc(18)/Kb(15) + Cc(15)*Cc(21)/Kf(15));

% AKG Production:  CIT + NAD -> AKG + NADH + CO2
Ctrl(16) = ((Cc(27)*Sigma(27)/(Cc(26)*Sigma(26))) / ...
    (Krs(16) + Cc(27)*Sigma(27)/(Cc(26)*Sigma(26)))) * ...
    ((ADP_m_f/ATP_m_f) / (delta16*Kps(16) + ADP_m_f/ATP_m_f));  
Rflux(16) = Vmax(16) * Ctrl(16) * Cc(16) / (Kf(16) + Cc(16));

% Succinyl-CoA Production:  AKG + CoA + NAD -> SCoA + NADH + CO2
Ctrl(17) = ((Cc(27)*Sigma(27)/(Cc(26)*Sigma(26))) / ...
    (Krs(17) + Cc(27)*Sigma(27)/(Cc(26)*Sigma(26)))) * ...
    ((ADP_m_f/ATP_m_f) / (delta17*Kps(17) + ADP_m_f/ATP_m_f));
Rflux(17) = Vmax(17) * Ctrl(17) * Cc(17)*Cc(25)*Sigma(25) / ...
     (Kf(17) + Cc(17)*Cc(25)*Sigma(25)); 

% Succinate Production:  SCoA + ADP + Pi -> SUC + CoA + ATP
Ctrl(18) = (ADP_m_f/ATP_m_f) / (Kps(18) + ADP_m_f/ATP_m_f);  
Rflux(18) = Vmax(18) * Ctrl(18) * Cc(18)*Cc(24)*Sigma(24) / ...
     (Kf(18) + Cc(18)*Cc(24)*Sigma(24)); 

% Malate Production:  SUC + NAD -> MAL + NADH	
Ctrl(19) = (Cc(27)*Sigma(27)/(Cc(26)*Sigma(26))) / ...
    (Krs(19) + Cc(27)*Sigma(27)/(Cc(26)*Sigma(26)));
Rflux(19) = Vmax(19) * Ctrl(19) * Cc(19) / (Kf(19) + Cc(19));

% Oxaloacetate Production:  MAL + NAD -> OXA + NADH
Ctrl(20) = (Cc(27)*Sigma(27)/(Cc(26)*Sigma(26))) / ...
    (Krs(20) + Cc(27)*Sigma(27)/(Cc(26)*Sigma(26)));
Rflux(20) = Vmax(20) * Ctrl(20) * Cc(20) / (Kf(20) + Cc(20));

% Oxygen Comsumption:  O2 + 6ADP + 6Pi + 2NADH -> H2O + 6ATP + 2NAD
Ctrl(21) =  ((Cc(26)*Sigma(26)/(Cc(27)*Sigma(27))) / ...
    (Krs(21) + Cc(26)*Sigma(26)/(Cc(27)*Sigma(27)))) * ...
    ((ADP_m_f/ATP_m_f) / (Kps(21) + ADP_m_f/ATP_m_f));  
Rflux(21) = Vmax(21) * Ctrl(21) * Cc(8)*Cc(24)*Sigma(24) / ...
    (Kf(21) + Cc(8)*Cc(24)*Sigma(24));

% PCr Breakdown:  PCr + ADP -> Cr + ATP
Ctrl(22) = (ADP_c_f/ATP_c_f) / (Kps(22) + ADP_c_f/ATP_c_f);
Rflux(22) = Vmax(22) * Ctrl(22) * Cc(22) / (Kf(22) + Cc(22));

% PCr Synthesis:  Cr + ATP -> PCr + ADP
Ctrl(23) = (ATP_c_f/ADP_c_f) / (Kps(23) + ATP_c_f/ADP_c_f);
Rflux(23) = Vmax(23) * Ctrl(23) * Cc(23) / (Kf(23) + Cc(23));

% ATP Hydrolysis:  ATP -> ADP + Pi
Ctrl(24) = 1.0 / (1.0 + epsilon24*Cc(24)/Kf(24));
Rflux(24) = Vmax(24) * Ctrl(24) * (ATP_c_f/ADP_c_f) / ...
    (Kps(24) + ATP_c_f/ADP_c_f);

% Adenylate Kinase-Forward:  AMP + ATP -> ADP + ADP
Ctrl(25) = (ATP_c_f/ADP_c_f) / (Kps(25) + ATP_c_f/ADP_c_f);
Rflux(25) = Vmax(25) * Ctrl(25) * Cc(30) / (Kf(25) + Cc(30));

% Adenylate Kinase-Reverse:  ADP + ADP -> AMP + ATP
Ctrl(26) = (ADP_c_f/ATP_c_f) / (Kps(26) + ADP_c_f/ATP_c_f);
Rflux(26) = Vmax(26) * Ctrl(26) * ADP_c_f / (Kf(26) + ADP_c_f);

%%
%******************************************************************************
% This section computes the production of the 30 species (the sum of all the
% reaction fluxes where the species is produced scaled by the corresponding 
% stochieometric coefficients)
%******************************************************************************

PROD = zeros(30,1);  
PROD(1) = 0;                                   % Glucose
PROD(2) = Rflux(6) + Rflux(8);                 % Pyruvate
PROD(3) = Rflux(7);                            % Lactate
PROD(4) = Rflux(9);                            % Alanine
PROD(5) = Rflux(11);                           % Glycerol
PROD(6) = 3*Rflux(11);                         % Free Fatty Acid
PROD(7) = Rflux(10) + Rflux(16) + Rflux(17);   % CO2
PROD(8) = 0;                                   % O2
PROD(9) = Rflux(1) + Rflux(3);                 % Glucose 6-Phosphate
PROD(10) = Rflux(2);                           % Glycogen
PROD(11) = 2*Rflux(4);                         % Glyceraldehyde 3-Phosphate
PROD(12) = Rflux(5);                           % 1,3-Biphosphoglycerate
PROD(13) = Rflux(12);                          % Triglyceride
PROD(14) = Rflux(13);                          % Fatty Acyl-CoA
PROD(15) = Rflux(10) + 8*Rflux(14);            % Acetyl-CoA
PROD(16) = Rflux(15);                          % Citrate
PROD(17) = Rflux(16);                          % Alpha-Ketoglutarate
PROD(18) = Rflux(17);                          % Succinyl-CoA
PROD(19) = Rflux(18);                          % Succinate
PROD(20) = Rflux(19);                          % Malate
PROD(21) = Rflux(20);                          % Oxaloacetate
PROD(22) = Rflux(23);                          % Phosphocreatine
PROD(23) = Rflux(22);                          % Creatine
PROD(24) = 2*Rflux(2) + Rflux(12) + 2*Rflux(13) + Rflux(24);  % Pi
PROD(25) = Rflux(15) + Rflux(18) + 3*Rflux(12);               % CoA
PROD(26) = Rflux(5) + Rflux(8) + Rflux(10) + 14*Rflux(14) ...
         + Rflux(16) + Rflux(17) + Rflux(19) + Rflux(20);     % NADH
PROD(27) = Rflux(7) + Rflux(12)+ 2*Rflux(21);                 % NAD
PROD(28) = 2*Rflux(6) + Rflux(18) + 6*Rflux(21) ...
         + Rflux(22) + Rflux(26);                             % ATP
PROD(29) = Rflux(1) + Rflux(2) + Rflux(4)+ 2*Rflux(13)  ...
         + Rflux(23) + Rflux(24) + 2*Rflux(25);               % ADP
PROD(30) = Rflux(26);                             % AMP

%%
%******************************************************************************
% This section computes the utilization of the 30 species (the sum of all the
% reaction fluxes where the species is consumed scaled by the corresponding 
% stochieometric coefficients).
%******************************************************************************

UTIL = zeros(30,1);  
UTIL(1) = Rflux(1);                            % Glucose
UTIL(2) = Rflux(7) + Rflux(9) + Rflux(10);     % Pyruvate
UTIL(3) = Rflux(8);                            % Lactate
UTIL(4) = 0;                                   % Alanine
UTIL(5) = 0;                                   % Glycerol
UTIL(6) = Rflux(13);                           % Fatty Acid
UTIL(7) = 0;                                   % CO2
UTIL(8) = Rflux(21);                           % O2
UTIL(9) = Rflux(2) + Rflux(4);                 % Glucose 6-Phosphate
UTIL(10) = Rflux(3);                           % Glycogen
UTIL(11) = Rflux(5) + Rflux(12);               % Glyceraldehyde 3-Phosphate
UTIL(12) = Rflux(6);                           % 1,3 Biphosphoglycerate
UTIL(13) = Rflux(11);                          % Triglyceride
UTIL(14) = Rflux(14)+3*Rflux(12);              % Fatty ACyl CoA
UTIL(15) = Rflux(15);                          % Acetyl-CoA
UTIL(16) = Rflux(16);                          % Citrate
UTIL(17) = Rflux(17);                          % alpha-Ketoglutarate
UTIL(18) = Rflux(18);                          % Succinyl-CoA
UTIL(19) = Rflux(19);                          % Succinate
UTIL(20) = Rflux(20);                          % Malate
UTIL(21) = Rflux(15);                          % Oxaloacetate
UTIL(22) = Rflux(22);                          % Phosphocreatine
UTIL(23) = Rflux(23);                          % Creatine
UTIL(24) = Rflux(3) + Rflux(5) + Rflux(18) + 6*Rflux(21);       % Pi
UTIL(25) = Rflux(10) + Rflux(13) + 7*Rflux(14) + Rflux(17);     % CoA
UTIL(26) = Rflux(12)+ Rflux(7) + 2*Rflux(21);                   % NADH
UTIL(27) = Rflux(5) + Rflux(8) + Rflux(10) + 14*Rflux(14) ...
         + Rflux(16) + Rflux(17) + Rflux(19) + Rflux(20);       % NAD
UTIL(28) = Rflux(1) + Rflux(2) + Rflux(4)+ 2*Rflux(13) ... 
          + Rflux(23) + Rflux(24) + Rflux(25);       % ATP
UTIL(29) = 2*Rflux(6) + Rflux(18) + 6*Rflux(21) ... 
         + Rflux(22) + 2*Rflux(26);                             % ADP
UTIL(30) = Rflux(25);                                           % AMP

%%
%******************************************************************************
% This section computes the metabolic reaction rate for the 30 species. This 
% section also computes the effective volumes for different species in blood 
% and cells (specifically O2 and CO2) and sets the differential equations 
% governing the transport and metabolism of species in blood and tissue cells.
%******************************************************************************

MRR = zeros(30,1);
MRR = PROD - UTIL;

[VbeffCO2] = VeffCO2_Blood(Vb,Visf,Cb(7));
[VbeffO2] = VeffO2_Blood(Vb,Visf,Cb(8));
Vbeff = (Vb+Visf)*ones(8,1);
Vbeff(7) = VbeffCO2; 
Vbeff(8) = VbeffO2; 

[VceffCO2] = VeffCO2_Cells(Vc,Cc(7));
[VceffO2] = VeffO2_Cells(Vc,Cc(8));
[VmeffCO2] = VeffCO2_Cells(Vm,Cc(7));
[VmeffO2] = VeffO2_Cells(Vm,Cc(8));

Vceff = Vc*ones(30,1);
Vmeff = Vm*ones(30,1);
Veff = Vceff + Sigma .* Vmeff;
Veff(7) = VceffCO2 + VmeffCO2;
Veff(8) = VceffO2 + VmeffO2;

Cbdot = zeros(8,1);
Ccdot = zeros(30,1);
Cdot  = zeros(38,1);

Cbdot = (AVD - URR) ./ Vbeff;
Ccdot(1:8) = (MRR(1:8) + URR(1:8)) ./ Veff(1:8);
Ccdot(9:30) = MRR(9:30) ./ Veff(9:30);
Cdot = [Cbdot;Ccdot];

% END OF DIFFERENTIAL EQUATIONS ***********************************************

%%
% START OF OTHER SUBFUNCTIONS USED IN THIS FUNCTION ***************************
%******************************************************************************
% Calculation of total CO2 concentration in blood (pH in plasma and RBC is 
% assumed to be constant; equal to 7.4 plasma and 7.24 in RBC).
%******************************************************************************

function [SHbCO2,CHbCO2,CHCO3,CO2Tot] = CO2Tot_Blood(CO2)

Hct = 0.45;                     % Standard hematocrit
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbCO2Max = 4*Hct*CHbrbc;       % HbCO2 concentration in blood at 100% HbO2 saturation (mM)
pHpl = 7.4;                     % Standard pH in plasma
pHrbc = 7.24;                   % Standard pH in RBC
CHpl = 10^(-pHpl+3);            % H+ concentration in plasma (mM)
CHrbc = 10^(-pHrbc+3);          % H+ concentration in RBC (mM)
Rrbc = CHpl/CHrbc;              % Gibb-Donnan equilibrium constant
KeqCO2hyd = 7.94e-4;            % Equilibrium constant for CO2 hydration (mM)
alphaCO2 = 3.05e-2;             % Solubility of CO2 in blood (mM/mmHg)
P50HbCO2 = 265.0;               % PCO2 at 50% HbCO2 saturation (mmHg)
C50HbCO2 = alphaCO2*P50HbCO2;   % Free CO2 concentration at 50% HbCO2 saturation (mM)
KHbCO2 = 1/C50HbCO2;            % Hill constant for SHbCO2 (mM^-1)

SHbCO2 = KHbCO2*CO2/(1+KHbCO2*CO2); % HbCO2 saturation (unitless)
CHbCO2 = CHbCO2Max*SHbCO2;      % Hb-bound CO2 concentration (mM)
CHCO3pl = KeqCO2hyd*CO2/CHpl;   % Concentration of HCO3 (bicarbonate) in plasma (mM)
CHCO3rbc = Rrbc*CHCO3pl;        % Concentration of HCO3m in RBC (mM)
CHCO3 = (1-Hct)*CHCO3pl + Hct*CHCO3rbc; % Concentration of HCO3m (mM) in blood
CO2Tot = CO2 + CHbCO2 + CHCO3;  % Total CO2 concentration (mM) in blood

%******************************************************************************
% Calculation of total CO2 concentration in tissue cells (pH in cells is
% assumed to be constant; equal to 7.1).
%******************************************************************************

function [CHCO3,CO2Tot] = CO2Tot_Cells(CO2)

pH = 7.1;                       % standard pH in cells
CH = 10^(-pH+3);                % H+ concentration in cells (mM)
KeqCO2hyd = 7.94e-4;            % Equilibrium constant for CO2 hydration (mM)
CHCO3 = KeqCO2hyd*CO2/CH;       % Concentration of HCO3 (bicarbonate) in cells (mM)
CO2Tot = CO2 + CHCO3;           % Total CO2 concentration in cells (mM)

%******************************************************************************
% Calculation of total O2 concentration in blood (pH in plasma and RBC is 
% assumed to be constant; equal to 7.4 plasma and 7.24 in RBC).
%******************************************************************************

function [SHbO2,CHbO2,O2Tot] = O2Tot_Blood(O2)

Hct = 0.45;                     % Standard hematocrit (unitless)
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbO2Max = 4*Hct*CHbrbc;        % HbO2 concentration at 100% HbO2 saturation (mM)
alphaO2 = 1.35e-3;              % Solubility of O2 in plasma (mM/mmHg)
P50HbO2 = 26.8;                 % PO2 at 50% HbO2 saturation (mmHg)
C50HbO2 = alphaO2*P50HbO2;      % Free O2 concentration at 50% HbO2 saturation (mM)
nH = 2.7;                       % Hill coefficient for SHbO2 (unitless)
KHbO2 = 1/C50HbO2^nH;           % Hill constant for SHbO2 (mM^-nH)

SHbO2 = KHbO2*O2^nH/(1+KHbO2*O2^nH);  % HbO2 saturation (unitless)
CHbO2 = CHbO2Max*SHbO2;         % Hb-bound O2 concentration in blood (mM)
O2Tot = O2 + CHbO2;             % Total O2 concentration in blood (mM) 

%**************************************************************************
% Calculation of total O2 concentration in muscle cells.
%**************************************************************************

function [SMbO2,CMbO2,O2Tot] = O2Tot_Cells(O2)

CMb = 0.5;                      % Concentration of myoglobin in cells (mM)
alphaO2 = 1.35e-3;              % Solubility of O2 in cells (mM/mmHg)
P50MbO2 = 2.4;                  % PO2 at 50% MbO2 saturation (mmHg)
C50MbO2 = alphaO2*P50MbO2;      % Free O2 concentration at 50% MbO2 saturation (mM)
KMbO2 = 1/C50MbO2;              % Hill constant for SMbO2 (mM^-1)

SMbO2 = KMbO2*O2/(1+KMbO2*O2);  % MbO2 saturation in tissue cells
CMbO2 = CMb*SMbO2;              % Mb-bound O2 concentration in cells (mM)
O2Tot = O2 + CMbO2;             % Total O2 concentration in cells (mM) 

%******************************************************************************
% Calculation of effective blood volume for CO2 accounting for different forms
% of CO2 transport in blood and ISF (pH in plasma, RBC and ISF is assumed to 
% be constant; equal to 7.4 plasma, 7.24 in RBC, and 7.2 in ISF).
%******************************************************************************

function [VbeffCO2] = VeffCO2_Blood(Vb,Visf,CO2)

Hct = 0.45;                     % Standard hematocrit (unitless)
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbCO2Max = 4*Hct*CHbrbc;       % HbCO2 concentration in blood at 100% HbO2 saturation (mM)
pHrbc = 7.24;                   % Standard pH in RBC
pHpl  = 7.4;                    % Standard pH in plasma
pHisf = 7.2;                    % Standard pH in ISF
CHrbc = 10^(-pHrbc+3);          % H+ concentration in RBC (mM)
CHpl  = 10^(-pHpl+3);           % H+ concentration in plasma (mM)
CHisf = 10^(-pHisf+3);          % H+ concentration in ISF (mM)
Rrbc = CHpl/CHrbc;              % Gibb-Donnan equilibrium constant for RBC
Rcap = CHpl/CHisf;              % Gibb-Donnan equilibrium constant for capillary
KeqCO2hyd = 7.94e-4;            % Equilibrium constant for CO2 hydration (mM)
alphaCO2 = 3.05e-2;             % Solubility of CO2 in plasma (mM/mmHg)
P50HbCO2 = 265.0;               % PCO2 at 50% HbCO2 saturation (mmHg)
C50HbCO2 = alphaCO2*P50HbCO2;   % Free CO2 concentration at 50% HbCO2 saturation (mM)
KHbCO2 = 1/C50HbCO2;            % Hill constant for SHbCO2 (mM^-1)

% Calculation of derivatives of state variables w.r.t. CO2 and then effective
% blood volume for CO2...
DSHbCO2 = KHbCO2/(1+KHbCO2*CO2)^2;
DCHbCO2 = CHbCO2Max*DSHbCO2;
DCHCO3pl = KeqCO2hyd/CHpl;
DCHCO3rbc = Rrbc*DCHCO3pl;
DCHCO3isf = Rcap*DCHCO3pl;
DCHCO3bl = (1-Hct)*DCHCO3pl + Hct*DCHCO3rbc;
VbeffCO2 = Vb*(1+DCHbCO2+DCHCO3bl) + Visf*(1+DCHCO3isf);

%******************************************************************************
% Calculation of effective cells volume for CO2 accounting for different forms
% of CO2 transport in cells (pH in cells is assumed to be constant = 7.1).
%******************************************************************************

function [VceffCO2] = VeffCO2_Cells(Vc,CO2)

pH = 7.1;                       % standard pH in cells
CH = 10^(-pH+3);                % H+ concentration in cells (mM)
KeqCO2hyd = 7.94e-4;            % Equilibrium constant for CO2 hydration (mM)
alphaCO2 = 3.05e-2;             % Solubility of CO2 in cells (mM/mmHg)
DCHCO3 = KeqCO2hyd/CH;          % dCHCO3/dCO2
VceffCO2 = Vc*(1+DCHCO3);       % Effective cells volume for CO2

%******************************************************************************
% Calculation of effective blood volume for O2 accounting for different forms
% of O2 transport in blood and ISF (pH in plasma and RBC is assumed to be 
% constant; equal to 7.4 plasma and 7.24 in RBC ).
%******************************************************************************

function [VbeffO2] = VeffO2_Blood(Vb,Visf,O2)

Hct = 0.45;                     % Standard hematocrit (unitless)
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbO2Max = 4*Hct*CHbrbc;        % HbO2 concentration at 100% HbO2 saturation (mM)
alphaO2 = 1.35e-3;              % Solubility of O2 in plasma (mM/mmHg)
P50HbO2 = 26.8;                 % PO2 at 50% HbO2 saturation (mmHg)
C50HbO2 = alphaO2*P50HbO2;      % Free O2 concentration at 50% HbO2 saturation (mM)
nH = 2.7;                       % Hill coefficient for SHbO2 (unitless)
KHbO2 = 1/C50HbO2^nH;           % Hill constant for SHbO2 (mM^-nH)

% Calculation of derivatives of state variables w.r.t. O2 and then effective
% blood volume for O2... 
DSHbO2 = nH*KHbO2*O2^(nH-1)/(1+KHbO2*O2^nH)^2;
DCHbO2 = CHbO2Max*DSHbO2;
VbeffO2 = Vb*(1+DCHbO2) + Visf;

%******************************************************************************
% Calculation of effective cell volume for O2 accounting for different forms 
% of O2 transport in cells (pH in cells is assumed to be constant = 7.1).
%******************************************************************************

function [VceffO2] = VeffO2_Cells(Vc,O2)

CMb = 0.5;                      % Concentration of myoglobin in cells (mM)
alphaO2 = 1.35e-3;              % Solubility of O2 in cells (mM/mmHg)
P50MbO2 = 2.4;                  % PO2 at 50% MbO2 saturation (mmHg)
C50MbO2 = alphaO2*P50MbO2;      % Free O2 concentration at 50% MbO2 saturation (mM)
KMbO2 = 1/C50MbO2;              % Hill constant for SMbO2 (mM^-1)
DSMbO2 = KMbO2/(1+KMbO2*O2)^2;  % dSMbO2/dO2
VceffO2 = Vc*(1+CMb*DSMbO2);    % Effective cells volume for O2

%%
%******************************************************************************
% Function to calculate the free Mg and free and Mg-bound ATP and ADP
%******************************************************************************
function [Mgf,ATPf,ADPf,ATPb,ADPb] = MgATPADP_rev(Mg,ATP,ADP)

KMgATP = 24e-3;    % Mg/ATP binding constant (mM)
KMgADP = 347e-3;   % Mg/ADP binding constant (mM)

%% If Mg is very small, then set Mg_f as zero and compute various forms
%  of ATP and ADP based on Mg_f = 0 and return. Else continue.
if (Mg <= 1e-12)
    Mgf = 0;
    ATPb = Mgf*ATP/(KMgATP + Mgf);
    ATPf = KMgATP*ATP/(KMgATP + Mgf);
    ADPb = Mgf*ADP/(KMgADP + Mgf);
    ADPf = KMgADP*ADP/(KMgADP + Mgf);
    return
 end
 
%% Coefficients of the polynomial involving free Mg
A0 = -Mg*KMgATP*KMgADP;
A1 = (KMgATP*KMgADP + KMgADP*ATP + KMgATP*ADP - Mg*KMgADP - Mg*KMgATP);
A2 = (KMgATP + KMgADP + ATP + ADP - Mg);
A3 = 1;

%% Iteration parameters and guesses
iter_max = 250;      % Maximum number of allowed iterations
err_tol = 1e-12;     % Tolerance for convergence

iter = 0;
error = 1.0;          % Initial error, an arbitraty large number
Mgf_old = Mg*10.0;    % Initial guess for free Mg (good guess is essential for convergence)
 
%% Newton-Raphson's iterative method for computing free Mg
while (iter < iter_max && error > err_tol)
    func = A3*Mgf_old^3 + A2*Mgf_old^2 + A1*Mgf_old + A0;
    dfunc = 3*A3*Mgf_old^2 + 2*A2*Mgf_old + A1;
    Mgf_new = Mgf_old - func/dfunc;
    if (Mgf_new <= 0)
	   fprintf('iter = %d, Mgf = %d, error = %d \n', iter, Mgf_new, error)
       disp('Mgf is negative during iteration')
	   disp('so the iteration scheme may not converge')
       disp('find a good initial guess for Mgf and restart')
	   disp('terminating the program')
	   return
    end
    error = abs(Mgf_new - Mgf_old)/Mgf_new;
    iter = iter + 1;
    Mgf_old = Mgf_new;
%    fprintf('iter = %d, Mgf = %d, error = %d \n', iter, Mgf_new, error)
end

if (iter == iter_max)
    fprintf('iter = %d, Mgf_new = %d, error = %d \n', iter, Mgf_new, error)
	disp('the iteration scheme didnot converge')
	disp('so the current Mgf may not be accurate')
    disp('terminating the program')
	return
end

%% Calculate the free Mg and free and Mg-bound ATP and ADP
Mgf = Mgf_new;
ATPb = Mgf*ATP/(KMgATP + Mgf);
ATPf = KMgATP*ATP/(KMgATP + Mgf);
ADPb = Mgf*ADP/(KMgADP + Mgf);
ADPf = KMgADP*ADP/(KMgADP + Mgf);

%%
%******************************************************************************
% Function to calculate the Mg-bound and total ATP/ADP from free ATP/ADP 
%******************************************************************************
function [Mgf,ATP,ADP,ATPb,ADPb] = MgATPADP_for(Mg,ATPf,ADPf)

KMgATP = 24e-3;    % Mg/ATP binding constant (mM)
KMgADP = 347e-3;   % Mg/ADP binding constant (mM)

Mgf = Mg / (1.0 + ATPf/KMgATP + ADPf/KMgADP);
ATPb = Mgf*ATPf/KMgATP;
ADPb = Mgf*ADPf/KMgADP;
ATP = (1.0 + Mgf/KMgATP)*ATPf;
ADP = (1.0 + Mgf/KMgADP)*ADPf;

%******************************************************************************
%                       End
%******************************************************************************
