%%
%*******************************************************************************
% This is the driver code for two compartmental lumped model of skeletal muscle 
% metabolism that can be used to simulate the metabolic responses of skeletal 
% muscle to physiological perurbation (eg, ischemia, hypoxia, exercise). 
%
% Developed by
%	Ranjan K. Dash (Ph.D.)
%	Senior Research Associate
%	Center for Modeling Integrated Metabolic Systems
%	Department of Pediatrics (Division of Cardiology)
%	Case Western Reserve University
%	Cleveland, OH 44106
%******************************************************************************

format long
       
% clc
% clf
% clear all
% close all

global URR0 Rflux0 Ca Cb0 Cc0 C0 MgATPADP0
global Vmus Qm Qisch Tmax Mm Lam Vmax Kf Kb Kps Krs Sigma
global Q UPT REL URR AVD Ctrl Rflux PROD UTIL MRR O2CO2 MgATPADP

%%
%*******************************************************************************
% This section reads the resting/steady state uptake-release rates of the 8 
% species and metabolic reaction fluxes of 26 reactions.
% This section also reads the arterial and initial (resting/steady state) blood
% and tissue cell concentrations of all the 30 species (substrates, intermediate 
% metabolites and controllers) in skeletal muscle. They are experimental values 
% obtained by biopsies/NMR (literature).
% Unit of concentrations: mmol/Kg WW (Kg WW = L). Unit of fluxes: mmol/min.
%*******************************************************************************

Flux0 = zeros(34,1);
URR0 = zeros(8,1);
Rflux0 = zeros(26,1);

Flux0 = dlmread('RestingFluxes.txt');
URR0(1:8) = Flux0(1:8);
Rflux0(1:26) = Flux0(9:34);

Conc0 = zeros(38,1);
Ca = zeros(8,1);
Cb0 = zeros(8,1);
Cc0 = zeros(30,1);
C0  = zeros(38,1);

Conc0 = dlmread('RestingConcentrations.txt');
Ca = Conc0(1:8);        % Resting arterial blood species concentrations
Cb0 = Conc0(9:16);      % Resting capillary blood species concentrations
Cc0 = Conc0(17:46);     % Resting muscle cells species concentrations
C0 = [Cb0;Cc0];         % Initial concentration vector

MgATPADP0 = zeros(15,1);
MgATPADP0 = dlmread('RestingMgATPADP.txt');

%%
%*******************************************************************************
% Read the estimated parameters from the file created from parameter estimation.
%*******************************************************************************

theta = zeros(187,1);
Tmax = zeros(8,1);
Mm = zeros(8,1);
Lam = zeros(8,1);
Vmax = zeros(26,1);
Kf = zeros(26,1);
Kb = zeros(26,1);
Kps = zeros(26,1);
Krs = zeros(26,1);
Sigma = zeros(30,1);

%theta = dlmread('InitialParameters_V2.1.txt');
theta = dlmread('EstimatedParameters_V2.1.txt');

Tmax(1:8) = theta(1:8);
Mm(1:8) = theta(9:16);
Lam(1:8) = theta(17:24);
Vmax(1:26)= theta(25:50);
Kf(1:26) = theta(51:76);
Kb(1:26) = theta(77:102);
Kps(1:26) = theta(103:128);
Krs(1:26) = theta(129:154);
Sigma(1:30)= theta(155:184);
Vmus = theta(185);
Qm = theta(186);
Qisch = theta(187);

Vmus = 4.0;
%Qisch = 0.18;
Qisch = 0.216;
%Qisch = 0.27;
%Qisch = 0.36;

%%
%*******************************************************************************
% Perturb the Michelis-Menten kinetic parameters (Km, Kps, Krs, Mm) and then 
% update the Vmax and Tmax parameters to match the steady-state conditions.
%*******************************************************************************
% 
% Kf(22) = Kf(22)/5;
% Kf(23) = Kf(23)/5;
%
% SkelMusMetab_TmaxVmax;
%
%theta = [Tmax;Mm;Lam;Vmax;Kf,Kb;Kps;Krs;Vmus;Qisch;Qm];
%dlmwrite('ModifiedParameters_V2.txt',theta,'precision','%13.6d');
%
%%
%******************************************************************************
% Call to the matlab ODE15S integrator to solve the stiff system of differential 
% equations dC/dt = f(C,t), where C is of length 39, the intial condition for 
% which is defined above.
%******************************************************************************

Tend = 65;             % End time of integration
Nstep = 65;            % Number of time steps
Tstep = Tend/Nstep;    % Time step of integration for ODE15S

Tspan = [0:Tstep:Tend];
options = odeset('RelTol',1e-8, 'AbsTol',1e-8, 'MaxStep',Tstep/50, ...
          'InitialStep',Tstep/500, 'MaxOrder',5, 'BDF','on');
%options = [];
[t,C] = ode15s(@SkelMusMetab_Cdot,Tspan,C0,options);

%%
%******************************************************************************
% Post processing of solutions to create data files and plot figures.
%******************************************************************************

Q_vec = [];
UPT_mat = [];
REL_mat = [];
URR_mat = [];
AVD_mat = [];
Ctrl_mat = [];
Rflux_mat = [];
PROD_mat = [];
UTIL_mat = [];
MRR_mat = [];
Cb_mat = [];
Cc_mat = [];
Cbdot_mat = [];
Ccdot_mat = [];
O2CO2_mat = [];
MgATPADP_mat = [];

for j = 1:Nstep+1
    tj = t(j);
    Cj = C(j,:)';
    [Cdotj] = SkelMusMetab_Cdot(tj,Cj);
    Q_vec = [Q_vec;Q];
    UPT_mat = [UPT_mat;UPT'];
    REL_mat = [REL_mat;REL'];
    URR_mat = [URR_mat;URR'];
    AVD_mat = [AVD_mat;AVD'];
    Ctrl_mat = [Ctrl_mat;Ctrl'];
    Rflux_mat = [Rflux_mat;Rflux'];
    PROD_mat = [PROD_mat;PROD'];
    UTIL_mat = [UTIL_mat;UTIL'];
    MRR_mat = [MRR_mat;MRR'];
    Cb_mat = [Cb_mat;Cj(1:8)'];
    Cc_mat = [Cc_mat;Cj(9:38)'];
    Cbdot_mat = [Cbdot_mat;Cdotj(1:8)'];
    Ccdot_mat = [Ccdot_mat;Cdotj(9:38)'];
    O2CO2_mat = [O2CO2_mat;O2CO2'];
    MgATPADP_mat = [MgATPADP_mat;MgATPADP'];
end
 
%%
%*******************************************************************************
% Experimental data of Katz et al. (1988) used for model validation and fitting.
%*******************************************************************************
texp = [0 5 35 50]';     % Time points of measurements
Cexp_mat = [0.4850  0.4850  0.6575  0.6525         % GLU    ydata(1:4)
            0.0425  0.0425  0.0925  0.0525         % PYR    ydata(5:8)
            0.6885  0.6885  1.5355  0.9400         % LAC    ydata(9:12)
            0.2400  0.2400  0.3750  0.2850         % G6P    ydata(13:16)
            20.100  20.100  16.850  20.225         % PCR    ydata(17:20)
            10.450  10.450  14.000  10.325         % CR     ydata(21:24)
            2.7000  2.7000  6.2500  2.6500         % Pi     ydata(25:28)
            6.1500  6.1500  6.2250  6.2000         % ATP    ydata(29:32)
            0.8200  0.8200  0.8850  0.8550         % ADP    ydata(33:36)
            0.0400  0.0400  0.0500  0.0420         % AMP    ydata(37:40)
            1.9700  1.9700  1.3500  2.0300         % PCR/CR ydata(40:44)
            16.200  16.200  16.600  17.900]';      % LAC/PYR ydata(44:48)

%*******************************************************************************
% Error lower bounds in the experimental data.
%*******************************************************************************
Cexp_matL =-[0.0575  0.0575  0.0925  0.0925        %GLU 
             0.0060  0.0060  0.0075  0.0075        %PYR
             0.1235  0.1235  0.3795  0.1155        %LAC
             0.0400  0.0400  0.0600  0.0375        %G6P
             0.6500  0.6500  1.1750  0.6000        %PCR
             0.7000  0.7000  1.1000  0.7000        %CR
             0.4000  0.4000  0.8000  0.4000        %Pi
             0.1750  0.1750  0.1750  0.1750        %ATP
             0.0250  0.0250  0.0450  0.0350        %ADP
             0.0050  0.0050  0.0075  0.0060        %AMP
             0.1200  0.1200  0.1300  0.1500        %PCR/CR
             2.9000  2.9000  4.1000  2.2000]';     %LAC/PYR

%*******************************************************************************
% Error upper bounds in the experimental data.
%*******************************************************************************
Cexp_matU = [0.0575  0.0575  0.0925  0.0925        %GLU 
             0.0060  0.0060  0.0075  0.0075        %PYR
             0.1235  0.1235  0.3795  0.1155        %LAC
             0.0400  0.0400  0.0600  0.0375        %G6P
             0.6500  0.6500  1.1750  0.6000        %PCR
             0.7000  0.7000  1.1000  0.7000        %CR
             0.4000  0.4000  0.8000  0.4000        %Pi
             0.1750  0.1750  0.1750  0.1750        %ATP
             0.0250  0.0250  0.0450  0.0350        %ADP
             0.0050  0.0050  0.0075  0.0060        %AMP
             0.1200  0.1200  0.1300  0.1500        %PCR/CR
             2.9000  2.9000  4.1000  2.2000]';     %LAC/PYR

%%
%******************************************************************************
%   Plots for Manuscript
%******************************************************************************

figure(1)
set(figure(1),'Units','inches','Position',[1.5 0.5 8 9])
 
subplot(3,2,1)
%subplot('position',[0.1 0.71 0.375 0.25]);
plot(t-5,Cc_mat(:,1)/Cc0(1),'-k','LineWidth',1.5)
axis([-5 Tend-5 0.75 1.75]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.75:0.25:1.75]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{GLC}(t) / C_{GLC}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on
errorbar(texp-5, Cexp_mat(:,1)/Cexp_mat(1,1), Cexp_matL(:,1)/Cexp_mat(1,1), ...
    Cexp_matU(:,1)/Cexp_mat(1,1), 'ks', 'MarkerFaceColor','k', 'MarkerSize',5, ...
    'LineWidth',1.5)
hold on
 
subplot(3,2,2)
%subplot('position',[0.575 0.71 0.375 0.25]);
plot(t-5,Cc_mat(:,9)/Cc0(9),'-k','LineWidth',1.5)
axis([-5 Tend-5 0.75 2.25]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.75:0.25:2.25]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{G6P}(t) / C_{G6P}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on
errorbar(texp-5, Cexp_mat(:,4)/Cexp_mat(1,4), Cexp_matL(:,4)/Cexp_mat(1,4), ...
    Cexp_matU(:,4)/Cexp_mat(1,4), 'ks', 'MarkerFaceColor','k', 'MarkerSize',5, ...
    'LineWidth',1.5);
hold on
 
subplot(3,2,3)
%subplot('position',[0.1 0.4 0.375 0.25]);
Tot_Pyr = (Cc_mat(:,2)*0.72 + Sigma(2)*Cc_mat(:,2)*0.08) / ...
    (Cc_mat(1,2)*0.72 + Sigma(2)*Cc_mat(1,2)*0.08);
plot(t-5,Tot_Pyr,'-k','LineWidth',1.5)
axis([-5 Tend-5 0.5 5.5]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.5:1.0:5.0]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{PYR}(t) / C_{PYR}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on
errorbar(texp-5, Cexp_mat(:,2)/Cexp_mat(1,2), Cexp_matL(:,2)/Cexp_mat(1,2), ...
    Cexp_matU(:,2)/Cexp_mat(1,2), 'ks', 'MarkerFaceColor','k', 'MarkerSize',5, ...
    'LineWidth',1.5);
hold on
 
subplot(3,2,4)
%subplot('position',[0.575 0.4 0.375 0.25]);
plot(t-5,Cc_mat(:,3)/Cc0(3),'-k','LineWidth',1.5)
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{LAC}(t) / C_{LAC}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
axis([-5 Tend-5 0.75 3.25]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.75:0.5:3.25]);
hold on
errorbar(texp-5, Cexp_mat(:,3)/Cexp_mat(1,3), Cexp_matL(:,3)/Cexp_mat(1,3), ...
    Cexp_matU(:,3)/Cexp_mat(1,3), 'ks', 'MarkerFaceColor','k', 'MarkerSize',5, ...
    'LineWidth',1.5);
hold on

subplot(3,2,5)
%subplot('position',[0.1 0.09 0.375 0.25]);
Tot_NADH = (Cc_mat(:,26)*0.72 + Sigma(26)*Cc_mat(:,26)*0.08) / ...
    (Cc_mat(1,26)*0.72 + Sigma(26)*Cc_mat(1,26)*0.08);
plot(t-5,Tot_NADH,'-k','LineWidth',1.5)
axis([-5 Tend-5 0.75 2.75]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.75:0.5:2.75]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{NADH}(t) / C_{NADH}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on

subplot(3,2,6)
%subplot('position',[0.575 0.09 0.375 0.25]);
Tot_NAD = (Cc_mat(:,27)*0.72 + Sigma(27)*Cc_mat(:,27)*0.08) / ...
    (Cc_mat(1,27)*0.72 + Sigma(27)*Cc_mat(1,27)*0.08);
plot(t-5,Tot_NAD,'-k','LineWidth',1.5)
axis([-5 Tend-5 0.8 1.05]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.8:0.05:1.05]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{NAD+}(t) / C_{NAD+}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on

% subplot(3,2,5)
% %subplot('position',[0.1 0.09 0.375 0.25]);
% plot(t-5,Cc_mat(:,26)/Cc0(26),'-k','LineWidth',1.5)
% axis([-5 Tend-5 0.75 2.0]);
% %axis 'autoy'
% set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
% set(gca, 'XTick', [-5,0:15:60]);
% set(gca, 'YTick', [0.75:0.25:2.0]);
% xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
% ylabel('C_{NADH}(t) / C_{NADH}(t = 0) in Cytosol', 'FontName','TimesNewRoman', ...
%     'FontSize',10)
% hold on
%  
% subplot(3,2,6)
% %subplot('position',[0.575 0.09 0.375 0.25]);
% plot(t-5,Cc_mat(:,27)/Cc0(27),'-k','LineWidth',1.5)
% axis([-5 Tend-5 0.85 1.05]);
% %axis 'autoy'
% set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
% set(gca, 'XTick', [-5,0:15:60]);
% set(gca, 'YTick', [0.85:0.05:1.05]);
% xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
% ylabel('C_{NAD+}(t) / C_{NAD+}(t = 0) in Cytosol', 'FontName','TimesNewRoman', ...
%     'FontSize',10)
% hold on

%%
%******************************************************************************

figure(2)
set(figure(2),'Units','inches','Position',[1.5 0.5 8 9])

subplot(3,2,1)
%subplot('position',[0.1 0.71 0.375 0.25]);
plot(t-5,Cc_mat(:,22)/Cc0(22),'-k','LineWidth',1.5)
axis([-5 Tend-5 0.6 1.1]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.6:0.1:1.1]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{PCR}(t) / C_{PCR}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on
errorbar(texp-5, Cexp_mat(:,5)/Cexp_mat(1,5), Cexp_matL(:,5)/Cexp_mat(1,5), ...
    Cexp_matU(:,5)/Cexp_mat(1,5), 'ks', 'MarkerFaceColor','k', 'MarkerSize',5, ...
    'LineWidth',1.5)
hold on
 
subplot(3,2,2)
%subplot('position',[0.575 0.71 0.375 0.25]);
plot(t-5,Cc_mat(:,23)/Cc0(23),'-k','LineWidth',1.5)
axis([-5 Tend-5 0.75 1.75]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.75:0.25:1.75]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{CR}(t) / C_{CR}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on
errorbar(texp-5, Cexp_mat(:,6)/Cexp_mat(1,6), Cexp_matL(:,6)/Cexp_mat(1,6), ...
    Cexp_matU(:,6)/Cexp_mat(1,6), 'ks', 'MarkerFaceColor','k', 'MarkerSize',5, ...
    'LineWidth',1.5);
hold on
 
subplot(3,2,3)
%subplot('position',[0.1 0.4 0.375 0.25]);
Tot_Pi = (Cc_mat(:,24)*0.72 + Sigma(24)*Cc_mat(:,24)*0.08) / ...
    (Cc_mat(1,24)*0.72 + Sigma(24)*Cc_mat(1,24)*0.08);
plot(t-5,Tot_Pi,'-k','LineWidth',1.5)
axis([-5 Tend-5 0.5 3.5]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.5:0.5:3.5]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{PI}(t) / C_{PI}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on
errorbar(texp-5, Cexp_mat(:,7)/Cexp_mat(1,7), Cexp_matL(:,7)/Cexp_mat(1,7), ...
    Cexp_matU(:,7)/Cexp_mat(1,7), 'ks', 'MarkerFaceColor','k', 'MarkerSize',5, ...
    'LineWidth',1.5);
hold on

subplot(3,2,4)
%subplot('position',[0.575 0.4 0.375 0.25]);
Tot_ATP = (Cc_mat(:,28)*0.72 + Sigma(28)*Cc_mat(:,28)*0.08) / ...
    (Cc_mat(1,28)*0.72 + Sigma(28)*Cc_mat(1,28)*0.08);
plot(t-5,Tot_ATP,'-k','LineWidth',1.5)
axis([-5 Tend-5 0.9 1.1]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.9:0.05:1.1]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{ATP}(t) / C_{ATP}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on
errorbar(texp-5, Cexp_mat(:,8)/Cexp_mat(1,8), Cexp_matL(:,8)/Cexp_mat(1,8), ...
    Cexp_matU(:,8)/Cexp_mat(1,8), 'ks', 'MarkerFaceColor','k', 'MarkerSize',5, ...
    'LineWidth',1.5);
hold on
 
subplot(3,2,5)
%subplot('position',[0.1 0.09 0.375 0.25]);
Tot_ADP = (Cc_mat(:,29)*0.72 + Sigma(29)*Cc_mat(:,29)*0.08) / ...
    (Cc_mat(1,29)*0.72 + Sigma(29)*Cc_mat(1,29)*0.08);
plot(t-5,Tot_ADP,'-k','LineWidth',1.5)
axis([-5 Tend-5 0.95 1.15]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.95:0.05:1.15]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{ADP}(t) / C_{ADP}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on
errorbar(texp-5, Cexp_mat(:,9)/Cexp_mat(1,9), Cexp_matL(:,9)/Cexp_mat(1,9), ...
    Cexp_matU(:,9)/Cexp_mat(1,9), 'ks', 'MarkerFaceColor','k', 'MarkerSize',5, ...
    'LineWidth',1.5);
hold on
 
subplot(3,2,6)
%subplot('position',[0.575 0.09 0.375 0.25]);
plot(t-5,Cc_mat(:,30)/Cc0(30),'-k','LineWidth',1.5)
axis([-5 Tend-5 0.75 1.75]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.75:0.25:1.75]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{AMP}(t) / C_{AMP}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on
errorbar(texp-5, Cexp_mat(:,10)/Cexp_mat(1,10), Cexp_matL(:,10)/Cexp_mat(1,10), ...
    Cexp_matU(:,10)/Cexp_mat(1,10), 'ks', 'MarkerFaceColor','k', 'MarkerSize',5, ...
    'LineWidth',1.5);
hold on

%%
%******************************************************************************
%   LAC/PYR, NAD+/NADH, PCR/CR and ATP/ADP ratios (extra plots)
%******************************************************************************

figure(3)
set(figure(3),'Units','inches','Position',[1.5 0.5 8 9])

subplot(3,2,1)
%subplot('position',[0.1 0.71 0.375 0.25]);
plot(t-5,Cc_mat(:,27)./Cc_mat(:,26),'-k','LineWidth',1.5)
axis([-5 Tend-5 100 600]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [100:100:600]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{NAD+}(t) / C_{NADH}(t) in Cytosol', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on

subplot(3,2,2)
%subplot('position',[0.575 0.71 0.375 0.25]);
plot(t-5,(Cc_mat(:,27)*Sigma(27))./(Cc_mat(:,26)*Sigma(26)),'-k','LineWidth',1.5)
axis([-5 Tend-5 1 7]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [1:1.5:7]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{NAD+}(t) / C_{NADH}(t) in Mitochondria', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on

subplot(3,2,3)
%subplot('position',[0.1 0.4 0.375 0.25]);
plot(t-5,Cc_mat(:,3)./Cc_mat(:,2),'-k','LineWidth',1.5)
axis([-5 Tend-5 5 45]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [5:10:45]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{LAC}(t) / C_{PYR}(t) in Cytosol', 'FontName','TimesNewRoman', ...
    'FontSize',10)
hold on

subplot(3,2,4)
%subplot('position',[0.575 0.4 0.375 0.25]);
plot(t-5,Cc_mat(:,22)./Cc_mat(:,23),'-k','LineWidth',1.5)
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{PCR}(t) / C_{CR}(t) in Cytosol', 'FontName','TimesNewRoman', ...
    'FontSize',10)
axis([-5 Tend-5 0.75 2.25]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.75:0.25:2.25]);
hold on

subplot(3,2,5)
%subplot('position',[0.1 0.09 0.375 0.25]);
plot(t-5,Cc_mat(:,28)./Cc_mat(:,29),'-k','LineWidth',1.5)
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{ATP}(t) / C_{ADP}(t) in Cytosol', 'FontName','TimesNewRoman', ...
    'FontSize',10)
axis([-5 Tend-5 290 340]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [290:10:340]);
hold on 

subplot(3,2,6)
%subplot('position',[0.575 0.09 0.375 0.25]);
plot(t-5,(Cc_mat(:,28)*Sigma(28))./(Cc_mat(:,29)*Sigma(29)),'-k','LineWidth',1.5)
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{ATP}(t) / C_{ADP}(t) in Mitochondria', 'FontName','TimesNewRoman', ...
    'FontSize',10)
axis([-5 Tend-5 0.95 1.15]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.95:0.05:1.15]);
hold on 

%%
%******************************************************************************
figure(4)
set(figure(4),'Units','inches','Position',[1.5 0.5 8 9])

subplot(4,2,1);
%subplot('position',[0.1 0.775 0.375 0.175]);
plot(t-5,Cc_mat(:,14)/Cc0(14),'-k','LineWidth',1.5);
axis([-5 Tend-5 0.5 1.3]);
%axis 'autoy';
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.5:0.2:1.3]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{FAC}(t) / C_{FAC}(t = 0) in Cells', 'FontName','TimesNewRoman',...
    'FontSize',10);
hold on

subplot(4,2,2)
%subplot('position',[0.575 0.775 0.375 0.175]);
plot(t-5,Cc_mat(:,15)/Cc0(15),'-k','LineWidth',1.5)
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{ACoA}(t) / C_{ACoA}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
axis([-5 Tend-5 0 60]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0:15:60]);
hold on

subplot(4,2,3)
%subplot('position',[0.1 0.54 0.375 0.175]);
plot(t-5,Cc_mat(:,16)/Cc0(16),'-k','LineWidth',1.5)
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{CIT}(t) / C_{CIT}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
axis([-5 Tend-5 0.9 1.05]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.9:0.05:1.05]);
hold on

subplot(4,2,4)
%subplot('position',[0.575 0.54 0.375 0.175]);
plot(t-5,Cc_mat(:,17)/Cc0(17),'-k','LineWidth',1.5)
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{AKG}(t) / C_{AKG}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
axis([-5 Tend-5 0.3 1.5]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.3:0.3:1.5]);
hold on

subplot(4,2,5)
%subplot('position',[0.1 0.305 0.375 0.175]);
plot(t-5,Cc_mat(:,18)/Cc0(18),'-k','LineWidth',1.5)
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{SCoA}(t) / C_{SCoA}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
axis([-5 Tend-5 0 1.2]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0:0.3:1.2]);
hold on

subplot(4,2,6)
%subplot('position',[0.575 0.305 0.375 0.175]);
plot(t-5,Cc_mat(:,19)/Cc0(19),'-k','LineWidth',1.5)
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{SUC}(t) / C_{SUC}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10)
axis([-5 Tend-5 0.5 2.5]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.5:0.5:2.5]);
hold on

subplot(4,2,7);
%subplot('position',[0.1 0.07 0.375 0.175]);
plot(t-5,Cc_mat(:,20)/Cc0(20),'-k','LineWidth',1.5);
axis([-5 Tend-5 0.9 1.3]);
%axis 'autoy';
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.9:0.1:1.3]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('C_{MAL}(t) / C_{MAL}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10);
hold on;

subplot(4,2,8);
%subplot('position',[0.575 0.07 0.375 0.175]);
plot(t-5,Cc_mat(:,21)/Cc0(21),'-k','LineWidth',1.5);
axis([-5 Tend-5 0.0 1.2]);
%axis 'autoy';
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.0:0.3:1.2]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10');
ylabel('C_{OXA}(t) / C_{OXA}(t = 0) in Cells', 'FontName','TimesNewRoman', ...
    'FontSize',10);
hold on;

%% 
%******************************************************************************
figure(5)
set(figure(5),'Units','inches','Position',[1.5 0.5 8 9])

subplot(3,2,1) 
%subplot('position',[0.1 0.72 0.375 0.24]);
plot(t-5,AVD_mat(:,1),'--k', t-5,URR_mat(:,1),':k', t-5,-MRR_mat(:,1),'-k', ...
    'LineWidth',1.5);
axis([-5 Tend-5 0.05 0.4]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.05:0.07:0.4]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('Fluxes of Glucose [mmol/min]', 'FontName','TimesNewRoman', 'FontSize',10);
legend('Q(C_a-C_v)', 'J_{b \leftrightarrow c}', '-(P_c-U_c)', 2);
%hold on

subplot(3,2,2)
%subplot('position',[0.575 0.72 0.375 0.24]);
plot(t-5,AVD_mat(:,2),'--k', t-5,URR_mat(:,2),':k', t-5,-MRR_mat(:,2),'-k', ...
    'LineWidth',1.5);
axis([-5 Tend-5 -0.08 0.04]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [-0.08:0.04:0.04]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('Fluxes of Pyruvate [mmol/min]', 'FontSize',10);
legend('Q(C_a-C_v)', 'J_{b \leftrightarrow c}', '-(P_c-U_c)', 3);
%hold on

subplot(3,2,3)
%subplot('position',[0.1 0.41 0.375 0.24]);
plot(t-5,-AVD_mat(:,3),'--k', t-5,-URR_mat(:,3),':k', t-5,MRR_mat(:,3),'-k', ...
    'LineWidth',1.5);
axis([-5 Tend-5 0 0.5]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0:0.1:0.5]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('Fluxes of Lactate [mmol/min]', 'FontName','TimesNewRoman', 'FontSize',10);
legend('-Q(C_a-C_v)', '-J_{b \leftrightarrow c}', '(P_c-U_c)', 2);
%hold on

subplot(3,2,4)
%subplot('position',[0.575 0.41 0.375 0.24]);
plot(t-5,AVD_mat(:,6),'--k', t-5,URR_mat(:,6),':k', t-5,-MRR_mat(:,6),'-k', ...
    'LineWidth',1.5);
axis([-5 Tend-5 0.0 0.2]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.0:0.05:0.2]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('Fluxes of Fatty Acid [mmol/min]', 'FontSize',10);
legend('Q(C_a-C_v)', 'J_{b \leftrightarrow c}', '-(P_c-U_c)', 2);
%hold on

subplot(3,2,5)
%subplot('position',[0.1 0.1 0.375 0.24]);
plot(t-5,-AVD_mat(:,7),'--k', t-5,-URR_mat(:,7),':k', t-5,MRR_mat(:,7),'-k', ...
    'LineWidth',1.5);
axis([-5 Tend-5 0 4]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0:1:4]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('Fluxes of CO_2 [mmol/min]', 'FontName','TimesNewRoman', 'FontSize',10);
legend('-Q(C_a-C_v)', '-J_{b \leftrightarrow c}', '(P_c-U_c)', 2);
%hold on

subplot(3,2,6)
%subplot('position',[0.575 0.1 0.375 0.24]);
plot(t-5,AVD_mat(:,8),'--k', t-5,URR_mat(:,8),':k', t-5,-MRR_mat(:,8),'-k', ...
    'LineWidth',1.5);
axis([-5 Tend-5 1.0 4.2]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [1:0.8:4.2]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('Fluxes of O_2 [mmol/min]', 'FontName','TimesNewRoman', 'FontSize',10);
legend('Q(C_a-C_v)', 'J_{b \leftrightarrow c}', '-(P_c-U_c)', 2);
%hold on

%%
%******************************************************************************
figure(6)
set(figure(6),'Units','inches','Position',[1.5 1.5 8 6])

subplot(2,2,1)
%subplot('position',[0.1 0.575 0.325 0.35]);
alphaO2 = 1.35e-3;           % Solubility of O2 in blood (mM/mmHg)
[AX,H1,H2] = plotyy(t-5,O2CO2_mat(:,3),t-5,O2CO2_mat(:,1)/alphaO2,'plot');
set(H1,'LineStyle','-', 'Color','k', 'LineWidth',1.5)
set(H2,'LineStyle','--', 'Color','k', 'LineWidth',1.5)
axis(AX(1),[-5 Tend-5 0 7.5]);
axis(AX(2),[-5 Tend-5 0 40]);
%axis(AX(1), 'autoy')
%axis(AX(2), 'autoy')
set(AX(1), 'LineWidth',1.5, 'FontName','TimesNewRoman', 'FontSize',10);
set(AX(2), 'LineWidth',1.5, 'FontName','TimesNewRoman', 'FontSize',10);
set(AX(1), 'XTick',[-5,0:15:Tend-5], 'YTick',[0:1.5:7.5], 'Ycolor','k');
set(AX(2), 'XTick',[], 'YTick',[0:8:40], 'Ycolor','k');
legend(AX(1), {'[O_2]'}, 'Color',[1 1 1], 'EdgeColor',[1 1 1], 'Location','East');
legend(AX(2), {'P_{O2}'}, 'Color',[1 1 1], 'EdgeColor',[1 1 1], 'Location','SouthEast');
xlabel('Time, t [min]', 'Color','k', 'FontName','TimesNewRoman', 'FontSize',10);
set(get(AX(1),'Ylabel'), 'String','Blood O_2 Content [mM]', 'Color','k', ...
    'FontName','TimesNewRoman', 'FontSize',10)
set(get(AX(2),'Ylabel'), 'String','Blood P_{O2} [mmHg]', 'Color','k', ...
    'FontName','TimesNewRoman', 'FontSize',10)
% hold(AX(1),'on');
% hold(AX(2),'on');

subplot(2,2,2)
%subplot('position',[0.575 0.575 0.325 0.35]);
alphaO2 = 1.35e-3;           % Solubility of O2 in blood (mM/mmHg)
[AX,H1,H2] = plotyy(t-5,O2CO2_mat(:,6),t-5,O2CO2_mat(:,4)/alphaO2,'plot');
set(H1,'LineStyle','-', 'Color','k', 'LineWidth',1.5)
set(H2,'LineStyle','--', 'Color','k', 'LineWidth',1.5)
axis(AX(1),[-5 Tend-5 0 0.5]);
axis(AX(2),[-5 Tend-5 0 25]);
%axis(AX(1), 'autoy')
%axis(AX(2), 'autoy')
set(AX(1), 'LineWidth',1.5, 'FontName','TimesNewRoman', 'FontSize',10);
set(AX(2), 'LineWidth',1.5, 'FontName','TimesNewRoman', 'FontSize',10);
set(AX(1), 'XTick',[-5,0:15:Tend-5], 'YTick',[0:0.1:0.5], 'Ycolor','k');
set(AX(2), 'XTick',[], 'YTick',[0:5:25], 'Ycolor','k');
legend(AX(1), {'[O_2]'}, 'Color',[1 1 1], 'EdgeColor',[1 1 1], 'Location','East');
legend(AX(2), {'P_{O2}'}, 'Color',[1 1 1], 'EdgeColor',[1 1 1], 'Location','SouthEast');
xlabel('Time, t [min]', 'Color','k', 'FontName','TimesNewRoman', 'FontSize',10);
set(get(AX(1),'Ylabel'), 'String','Cell O_2 Content [mM]', 'Color','k', ...
    'FontName','TimesNewRoman', 'FontSize',10)
set(get(AX(2),'Ylabel'), 'String','Cell P_{O2} [mmHg]', 'Color','k', ...
    'FontName','TimesNewRoman', 'FontSize',10)
% hold(AX(1),'on');
% hold(AX(2),'on');

subplot(2,2,3)
%subplot('position',[0.1 0.125 0.325 0.35]);
alphaCO2 = 3.05e-2;          % Solubility of CO2 in blood (mM/mmHg)
[AX,H1,H2] = plotyy(t-5,O2CO2_mat(:,9),t-5,O2CO2_mat(:,8)/alphaCO2,'plot');
set(H1,'LineStyle','-', 'Color','k', 'LineWidth',1.5)
set(H2,'LineStyle','--', 'Color','k', 'LineWidth',1.5)
axis(AX(1),[-5 Tend-5 25 30]);
axis(AX(2),[-5 Tend-5 42 52]);
%axis(AX(1), 'autoy')
%axis(AX(2), 'autoy')
set(AX(1), 'LineWidth',1.5, 'FontName','TimesNewRoman', 'FontSize',10);
set(AX(2), 'LineWidth',1.5, 'FontName','TimesNewRoman', 'FontSize',10);
set(AX(1), 'XTick',[-5,0:15:Tend-5], 'YTick',[25:1:30], 'Ycolor','k');
set(AX(2), 'XTick',[], 'YTick',[42:2:52], 'Ycolor','k');
legend(AX(1), {'[CO_2]'}, 'Color',[1 1 1], 'EdgeColor',[1 1 1], 'Location','NorthEast');
legend(AX(2), {'P_{CO2}'}, 'Color',[1 1 1], 'EdgeColor',[1 1 1], 'Location','East');
xlabel('Time, t [min]', 'Color','k', 'FontName','TimesNewRoman', 'FontSize',10);
set(get(AX(1),'Ylabel'), 'String','Blood CO_2 Content [mM]', 'Color','k', ...
    'FontName','TimesNewRoman', 'FontSize',10)
set(get(AX(2),'Ylabel'), 'String','Blood P_{CO2} [mmHg]', 'Color','k', ...
    'FontName','TimesNewRoman', 'FontSize',10)
% hold(AX(1),'on');
% hold(AX(2),'on');

subplot(2,2,4)
%subplot('position',[0.575 0.125 0.325 0.35]);
alphaCO2 = 3.05e-2;          % Solubility of CO2 in blood (mM/mmHg)
[AX,H1,H2] = plotyy(t-5,O2CO2_mat(:,11),t-5,O2CO2_mat(:,10)/alphaCO2,'plot');
set(H1,'LineStyle','-', 'Color','k', 'LineWidth',1.5)
set(H2,'LineStyle','--', 'Color','k', 'LineWidth',1.5)
axis(AX(1),[-5 Tend-5 15 18]);
axis(AX(2),[-5 Tend-5 44 54]);
%axis(AX(1), 'autoy')
%axis(AX(2), 'autoy')
set(AX(1), 'LineWidth',1.5, 'FontName','TimesNewRoman', 'FontSize',10);
set(AX(2), 'LineWidth',1.5, 'FontName','TimesNewRoman', 'FontSize',10);
set(AX(1), 'XTick',[-5,0:15:Tend-5], 'YTick',[15:0.6:18], 'Ycolor','k');
set(AX(2), 'XTick',[], 'YTick',[44:2:54], 'Ycolor','k');
legend(AX(1), {'[CO_2]'}, 'Color',[1 1 1], 'EdgeColor',[1 1 1], 'Location','NorthEast');
legend(AX(2), {'P_{CO2}'}, 'Color',[1 1 1], 'EdgeColor',[1 1 1], 'Location','East');
xlabel('Time, t [min]', 'Color','k', 'FontName','TimesNewRoman', 'FontSize',10);
set(get(AX(1),'Ylabel'), 'String','Cell CO_2 Content [mM]', 'Color','k', ...
    'FontName','TimesNewRoman', 'FontSize',10)
set(get(AX(2),'Ylabel'), 'String','Cell P_{CO2} [mmHg]', 'Color','k', ...
    'FontName','TimesNewRoman', 'FontSize',10)
% hold(AX(1),'on');
% hold(AX(2),'on');

%%
%******************************************************************************
figure(7)
set(figure(7),'Units','inches','Position',[1.5 1.5 8 7])

subplot(2,2,1)
%subplot('position',[0.08 0.56 0.4 0.4]);
plot(t-5,Rflux_mat(:,10),'--k', t-5,Rflux_mat(:,14),':k', 'LineWidth',1.5);
axis([-5 Tend-5 0.05 0.3]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.05:0.05:0.3]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('Fluxes of ACoA [mmol/min]', 'FontName','TimesNewRoman', ...
    'FontSize',10);
legend('\phi_{PYR \rightarrow ACoA}', '\phi_{FAC \rightarrow ACoA}', 2);
%hold on

subplot(2,2,2)
%subplot('position',[0.56 0.56 0.4 0.4]);
plot(t-5,(Rflux_mat(:,10)+8*Rflux_mat(:,14)),'-k', ...
     t-5,Rflux_mat(:,15),'-.k', 'LineWidth',1.5);
axis([-5 Tend-5 0.5 1.1]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [0.5:0.1:1.1]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('Fluxes of ACoA [mmol/min]', 'FontName','TimesNewRoman', 'FontSize',10);
legend('\phi_{PYR \rightarrow ACoA} + 8\phi_{FAC \rightarrow ACoA}', ...
       '\phi_{ACoA \rightarrow CIT}', 1);
%hold on

subplot(2,2,3)
%subplot('position',[0.08 0.08 0.4 0.4]);
plot(t-5,Rflux_mat(:,24),'--k', t-5,6*Rflux_mat(:,21),':k', 'LineWidth',1.5);
axis([-5 Tend-5 10 17.5]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [10:1.5:17.5]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('Fluxes of ATP [mmol/min]', 'FontName','TimesNewRoman', ...
    'FontSize',10);
legend('\phi_{ATP \rightarrow ADP}', '6\phi_{O2 \rightarrow H2O}', 2);
%hold on

subplot(2,2,4)
%subplot('position',[0.56 0.08 0.4 0.4]);
plot(t-5,(Rflux_mat(:,24)-6*Rflux_mat(:,21)),'-k', ...
     t-5,(Rflux_mat(:,22)-Rflux_mat(:,23)),'-.k', 'LineWidth',1.5);
axis([-5 Tend-5 -3 4.5]);
%axis 'autoy'
set(gca, 'LineWidth',1.25, 'FontName','TimesNewRoman', 'FontSize',10);
set(gca, 'XTick', [-5,0:15:60]);
set(gca, 'YTick', [-3:1.5:4.5]);
xlabel('Time, t [min]', 'FontName','TimesNewRoman', 'FontSize',10);
ylabel('Fluxes of ATP [mmol/min]', 'FontName','TimesNewRoman', 'FontSize',10);
legend('\phi_{ATP \rightarrow ADP}-6\phi_{O2 \rightarrow H2O}', ...
    '\phi_{PCR \leftrightarrow CR}', 1);
%hold on

%**************************************************************************
%                                    END
%**************************************************************************
