%*******************************************************************************
% This function computes the new Vmax and Tmax values from the resting/steady 
% state uptake-release rates (URR0) and metabolic reaction fluxes (Rflux0) with
% the given updated Mm, Km, Kps and Krs values. This recalculation of Tmax and  
% Vmax values are important for maintaining the resting/steady state conditions. 
%*******************************************************************************

function SkelMusMetab_TmaxVmax

format long e

% These parameters are passed here from the main/driver routine.
global URR0 Rflux0 Ca Cb0 Cc0 C0 MgATPADP0
global Vmus Qm Qisch Tmax Mm Lam Vmax Kf Kb Kps Krs Sigma

%*******************************************************************************
% This section computes new Tmax values given the updated Mm values (passed 
% here through the global statement) and resting/steady state conditions.
%*******************************************************************************

diff1 = Cb0(1)/(Mm(1)+Cb0(1)) - Cc0(1)/(Mm(1)+Cc0(1));
diff2 = Cb0(2)/(Mm(2)+Cb0(2)) - Cc0(2)/(Mm(2)+Cc0(2));
diff3 = Cb0(3)/(Mm(3)+Cb0(3)) - Cc0(3)/(Mm(3)+Cc0(3));
diff6 = Cb0(6)/(Mm(6)+Cb0(6)) - Cc0(6)/(Mm(6)+Cc0(6));

Tmax(1) = URR0(1)/diff1;     % Tmax for uptake of GLU from blood
Tmax(2) = URR0(2)/diff2;     % Tmax for uptake of Pyr from blood
Tmax(3) = URR0(3)/diff3;     % Tmax for release of LAC to blood
Tmax(6) = URR0(6)/diff6;     % Tmax for uptake of FFA to blood

%%
%******************************************************************************
% This section computes new Vmax values given the updated Mm, Km, Kps and Krs
% values (passed here through the global statement) and resting/steady state 
% conditions (Rflux0 and Cc00 values). 
%******************************************************************************

Ctrl0 = ones(26,1);
Fact0 = zeros(26,1);

% Set on/off switches for inhibition
epsilon01 = 1.0;    % Glucose Utilization
epsilon10 = 0.0;    % PDH reaction
epsilon15 = 0.0;    % Citrate production
epsilon24 = 1.0;    % ATP hydrolysis

delta01 = 1.0;      % Glucose Utilization
delta03 = 1.0;      % Glycogen Utilization
delta10 = 0.0;      % PDH reaction
delta15 = 0.0;      % Citrate production
delta16 = 0.0;      % AKG production
delta17 = 0.0;      % SCoA production

% Set the resting free ATP/ADP concentrations in cytosol and mitochondria
ATP_c_f0 = MgATPADP0(2);
ADP_c_f0 = MgATPADP0(5);
ATP_m_f0 = MgATPADP0(9);
ADP_m_f0 = MgATPADP0(12);

% Glucose Utilization:  GLU + ATP -> G6P + ADP
Ctrl0(1) = (1.0 / (1.0 + delta01*Cc0(9)/Kb(1))) * ...
    ((ATP_c_f0/ADP_c_f0) / (Kps(1) + ATP_c_f0/ADP_c_f0));
Fact0(1) = Ctrl0(1) * (Cc0(1)/Kf(1)) / ...
    (1.0 + epsilon01*Cc0(9)/Kb(1) + Cc0(1)/Kf(1));

% Glycogen Synthesis:  G6P + ATP -> GLY + ADP + 2Pi
Ctrl0(2) = (ATP_c_f0/ADP_c_f0) / (Kps(2) + ATP_c_f0/ADP_c_f0); 
Fact0(2) = Ctrl0(2) * Cc0(9) / (Kf(2) + Cc0(9));

% Glycogen Utilization:  GLY + Pi -> G6P
Ctrl0(3) = (Cc0(30)/ATP_c_f0) / (delta03*Kps(3) + Cc0(30)/ATP_c_f0);  
Fact0(3) = Ctrl0(3) * Cc0(10)*Cc0(24) / (Kf(3) + Cc0(10)*Cc0(24));

% G6P Breakdown:  G6P + ATP -> 2GA3P + ADP
Ctrl0(4) = (ATP_c_f0/ADP_c_f0) / (Kps(4) + ATP_c_f0/ADP_c_f0);
Fact0(4) = Ctrl0(4) * Cc0(9) / (Kf(4) + Cc0(9));

% GA3P Breakdown:  GA3P + Pi + NAD -> BPG + NADH
Ctrl0(5) = (Cc0(27)/Cc0(26)) / (Krs(5) + Cc0(27)/Cc0(26)); 
Fact0(5) = Ctrl0(5) * Cc0(11)*Cc0(24) / (Kf(5) + Cc0(11)*Cc0(24));

% Pyruvate Production:  BPG + 2ADP -> PYR + 2ATP
Ctrl0(6) = (ADP_c_f0/ATP_c_f0) / (Kps(6) + ADP_c_f0/ATP_c_f0);
Fact0(6) = Ctrl0(6) * Cc0(12) / (Kf(6) + Cc0(12));

% Pyruvate Reduction:  PYR + NADH -> LAC + NAD
Ctrl0(7) = ((Cc0(26)/Cc0(27)) / (Krs(7) + (Cc0(26)/Cc0(27))));
Fact0(7) = Ctrl0(7) * Cc0(2) / (Kf(7) + Cc0(2));

% Lactate Oxidation:  LAC + NAD -> PYR + NADH
Ctrl0(8) = ((Cc0(27)/Cc0(26)) / (Krs(8) + (Cc0(27)/Cc0(26))));
Fact0(8) = Ctrl0(8) * Cc0(3) / (Kf(8) + Cc0(3));

% Alanine Production:  PYR -> ALA
Fact0(9) = Cc0(2) / (Kf(9) + Cc0(2));

% Pyruvate Oxidation:  PYR + CoA + NAD -> ACoA + NADH + CO2
Ctrl0(10) = ((Cc0(27)*Sigma(27)/(Cc0(26)*Sigma(26))) / ...
    (Krs(10) + Cc0(27)*Sigma(27)/(Cc0(26)*Sigma(26)))) * ...
    ((ADP_m_f0/ATP_m_f0) /(delta10*Kps(10) + ADP_m_f0/ATP_m_f0));
Fact0(10) = Ctrl0(10) * (Cc0(2)*Sigma(2)*Cc0(25)*Sigma(25)/Kf(10)) / ...
    (1.0 + epsilon10*Cc0(15)*Cc0(26)*Sigma(26)/Kb(10) + ...
    Cc0(2)*Sigma(2)*Cc0(25)*Sigma(25)/Kf(10));

% Lipolysis:  TGL -> GLC + 3FFA
Fact0(11) = Cc0(13) / (Kf(11) + Cc0(13)); 

% Triglyceride Synthesis:  GA3P + 3FAC + NADH -> TGL + 3CoA + NAD + Pi
Ctrl0(12) = (Cc0(26)/Cc0(27)) / (Krs(12) + Cc0(26)/Cc0(27));
Fact0(12) = Ctrl0(12) * Cc0(11)*Cc0(14) / (Kf(12) + Cc0(11)*Cc0(14));
    
% Free Fatty Acid Utilization:  FFA + CoA + 2ATP -> FAC + 2ADP + 2Pi
Ctrl0(13) = (ATP_c_f0/ADP_c_f0) / (Kps(13) + ATP_c_f0/ADP_c_f0);  
Fact0(13) = Ctrl0(13) * Cc0(6)*Cc0(25) / (Kf(13) + Cc0(6)*Cc0(25));

% FAC Oxidation:  FAC + 7CoA + 14NAD -> 8ACoA + 14NADH
Ctrl0(14) = (Cc0(27)*Sigma(27)/(Cc0(26)*Sigma(26))) / ...
    (Krs(14) + Cc0(27)*Sigma(27)/(Cc0(26)*Sigma(26)));
Fact0(14) = Ctrl0(14) * Cc0(14)*Sigma(14)*Cc0(25)*Sigma(25) / ...
    (Kf(14) + Cc0(14)*Sigma(14)*Cc0(25)*Sigma(25));

% Citrate Production:  ACoA + OXA -> CIT + CoA
Ctrl0(15) = (ADP_m_f0/ATP_m_f0) / (delta15*Kps(15) + ADP_m_f0/ATP_m_f0);
Fact0(15) = Ctrl0(15) * (Cc0(15)*Cc0(21)/Kf(15)) / ...
    (1.0 + epsilon15*Cc0(18)/Kb(15) + Cc0(15)*Cc0(21)/Kf(15));

% AKG Production:  CIT + NAD -> AKG + NADH + CO2
Ctrl0(16) = ((Cc0(27)*Sigma(27)/(Cc0(26)*Sigma(26))) / ...
    (Krs(16) + Cc0(27)*Sigma(27)/(Cc0(26)*Sigma(26)))) * ...
    ((ADP_m_f0/ATP_m_f0) / (delta16*Kps(16) + ADP_m_f0/ATP_m_f0));  
Fact0(16) = Ctrl0(16) * Cc0(16) / (Kf(16) + Cc0(16));

% Succinyl-CoA Production:  AKG + CoA + NAD -> SCoA + NADH + CO2
Ctrl0(17) = ((Cc0(27)*Sigma(27)/(Cc0(26)*Sigma(26))) / ...
    (Krs(17) + Cc0(27)*Sigma(27)/(Cc0(26)*Sigma(26)))) * ...
    ((ADP_m_f0/ATP_m_f0) /(delta17*Kps(17) + ADP_m_f0/ATP_m_f0));
Fact0(17) = Ctrl0(17) * Cc0(17)*Cc0(25)*Sigma(25) / ...
    (Kf(17) + Cc0(17)*Cc0(25)*Sigma(25)); 

% Succinate Production:  SCoA + ADP + Pi -> SUC + CoA + ATP
Ctrl0(18) = (ADP_m_f0/ATP_m_f0) /(Kps(18) + ADP_m_f0/ATP_m_f0);  
Fact0(18) = Ctrl0(18) * Cc0(18)*Cc0(24)*Sigma(24) / ...
    (Kf(18) + Cc0(18)*Cc0(24)*Sigma(24)); 

% Malate Production:  SUC + (2/3)NAD -> MAL + (2/3)NADH	
Ctrl0(19) = (Cc0(27)*Sigma(27)/(Cc0(26)*Sigma(26))) / ...
    (Krs(19) + Cc0(27)*Sigma(27)/(Cc0(26)*Sigma(26)));
Fact0(19) = Ctrl0(19) * Cc0(19) / (Kf(19) + Cc0(19));

% Oxaloacetate Production:  MAL + NAD -> OXA + NADH
Ctrl0(20) = (Cc0(27)*Sigma(27)/(Cc0(26)*Sigma(26))) / ...
    (Krs(20) + Cc0(27)*Sigma(27)/(Cc0(26)*Sigma(26)));
Fact0(20) = Ctrl0(20) * Cc0(20) / (Kf(20) + Cc0(20));

% Oxygen Comsumption:  O2 + 6ADP + 6Pi + 2NADH -> H2O + 6ATP + 2NAD
Ctrl0(21) =  ((Cc0(26)*Sigma(26)/(Cc0(27)*Sigma(27))) / ...
    (Krs(21) + Cc0(26)*Sigma(26)/(Cc0(27)*Sigma(27)))) * ...
    ((ADP_m_f0/ATP_m_f0) / (Kps(21) + ADP_m_f0/ATP_m_f0));  
Fact0(21) = Ctrl0(21) * (Cc0(8)*Cc0(24)*Sigma(24)) / ...
    (Kf(21) + Cc0(8)*Cc0(24)*Sigma(24));

% PCr Breakdown:  PCr + ADP -> Cr + ATP
Ctrl0(22) = (ADP_c_f0/ATP_c_f0) / (Kps(22) + ADP_c_f0/ATP_c_f0);
Fact0(22) = Ctrl0(22) * Cc0(22) / (Kf(22) + Cc0(22));

% PCr Synthesis:  Cr + ATP -> PCr + ADP
Ctrl0(23) = (ATP_c_f0/ADP_c_f0) / (Kps(23) + ATP_c_f0/ADP_c_f0);
Fact0(23) = Ctrl0(23) * Cc0(23) / (Kf(23) + Cc0(23));

% ATP Hydrolysis:  ATP -> ADP + Pi
Ctrl0(24) = 1.0 / (1.0 + epsilon24*Cc0(24)/Kf(24));
Fact0(24) = Ctrl0(24) * ((ATP_c_f0/ADP_c_f0) / ...
    (Kps(24) + ATP_c_f0/ADP_c_f0));

% Adenylate Kinase-Forward:  AMP + ATP -> ADP + ADP
Ctrl0(25) = (ATP_c_f0/ADP_c_f0) / (Kps(25) + ATP_c_f0/ADP_c_f0);
Fact0(25) = Ctrl0(25) * Cc0(30) / (Kf(25) + Cc0(30));

% Adenylate Kinase-Reverse:  ADP + ADP -> AMP + ATP
Ctrl0(26) = (ADP_c_f0/ATP_c_f0) / (Kps(26) + ADP_c_f0/ATP_c_f0);
Fact0(26) = Ctrl0(26) * ADP_c_f0 / (Kf(26) + ADP_c_f0);

%%
%******************************************************************************
% This section computes the Vmax values of the 26 reactions.
%******************************************************************************

Vmax = zeros(26,1);
Vmax = Rflux0 ./ Fact0;

%******************************************************************************
%                  END OF THE FUNCTION
%******************************************************************************

